<?php

namespace CRM\Factory;

use Doctrine\ORM\EntityManager;
use CRM\Traits\TQuery;

class CrmClassificacaoDeTarefasFactory
{
    use TQuery;

    protected $connection;

    protected $entityManager;

    public function __construct(EntityManager $entityManager)
    {
        $this->connection = $entityManager->getConnection();
        $this->entityManager = $entityManager;
    }

    public function getCrmClassificacaoDeTarefas()
    {
        $sql = "SELECT * FROM CRM_CLASSIFICATAREFA ORDER BY NRSEQCLASSIFICATAREFA ASC";

        return $this->createAndExecuteQueryAndBuildResponseData($this->entityManager, $sql);
    }

    public function insertCrmClassificacaoDeTarefas( $params )
    {
        $sql = "INSERT INTO CRM_CLASSIFICATAREFA
                       (NRSEQCLASSIFICATAREFA,
                        DSCLASSIFICATAREFA,  
                        NRORG,
                        NRORGINCLUSAO,  
                        CDOPERINCLUSAO,
                        NRORGULTATU,  
                        CDOPERULTATU,    
                        IDATIVO,
                        DTINCLUSAO)        
                VALUES (:NRSEQCLASSIFICATAREFA,
                        :DSCLASSIFICATAREFA,  
                        :NRORG,
                        :NRORGINCLUSAO,  
                        :CDOPERINCLUSAO,
                        :NRORGULTATU,  
                        :CDOPERULTATU,    
                        :IDATIVO, 
                        SYSDATE)";
        $this->connection->executeStatement($sql, $params);
       
    }

    public function editCrmClassificacaoDeTarefas( $params )
    {
        
        $sql = "UPDATE CRM_CLASSIFICATAREFA
                SET 
                    DSCLASSIFICATAREFA         = :DSCLASSIFICATAREFA,
                    NRORG                      = :NRORG,
                    NRORGULTATU                = :NRORGULTATU,  
                    CDOPERULTATU               = :CDOPERULTATU,  
                    IDATIVO                    = :IDATIVO,
                    DTULTATU                   = SYSDATE
                WHERE NRSEQCLASSIFICATAREFA    = :NRSEQCLASSIFICATAREFA";
        $this->connection->executeStatement($sql, $params);

    }

    public function checkExistingClassificacaoDeTarefas($params)
    {
        $sql = "SELECT
                    COUNT(*) AS VALIDA
                FROM
                    CRM_CLASSIFICATAREFA
                WHERE
                       UPPER (DSCLASSIFICATAREFA) = UPPER (:DSCLASSIFICATAREFA)
                    AND NRORG = :NRORG  AND NRSEQCLASSIFICATAREFA <> :NRSEQCLASSIFICATAREFA";

        $std = $this->connection->prepare($sql);
        $std->execute($params);
        $retorno = $std->fetchAll();
        return $retorno[0]["VALIDA"];
    }

    public function deleteCrmClassificacaoDeTarefas($params)
    {  
        $sql = "DELETE FROM CRM_CLASSIFICATAREFA
                WHERE NRSEQCLASSIFICATAREFA = :NRSEQCLASSIFICATAREFA
                    AND NRORG               = :NRORG";
        $std = $this->connection->prepare($sql);
        $std->execute($params);
        
    }
    

}