<?php

namespace CRM\Service;

use CRM\Factory\CrmClassificacaoDeTarefasFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmClassificacaoDeTarefasService
{

    protected $ClassificacaoDeTarefasFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmClassificacaoDeTarefasFactory $ClassificacaoDeTarefasFactory)
    {
        $this->ClassificacaoDeTarefasFactory    = $ClassificacaoDeTarefasFactory;
        $this->Environment                      = $Environment;
        $this->newCode                          = $newCode;
        $this->connection                       = $entityManager->getConnection();
    }

    public function getCrmClassificacaoDeTarefas()
    {
        return $this->ClassificacaoDeTarefasFactory->getCrmClassificacaoDeTarefas();
    }

    public function saveCrmClassificacaoDeTarefas($rows)
    { 
       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();

        foreach ($rows["DRG"] as $row) {
            if ($row["NRSEQCLASSIFICATAREFA"] == 0) {
                $this->checkExistingClassificacaoDeTarefas($nrorg, $row);
                $novoCodigo = $this->newCode->getCodeByTableName("CRM_CLASSIFICATAREFA", $nrorg, 1, 5, false);

                $params = array(
                    "NRSEQCLASSIFICATAREFA"   => $novoCodigo,
                    "DSCLASSIFICATAREFA"      => $row["DSCLASSIFICATAREFA"],
                    "NRORG"                   => $nrorg,
                    "NRORGINCLUSAO"           => $nrorg,
                    "CDOPERINCLUSAO"          => $operador,
                    "NRORGULTATU"             => $nrorg,
                    "CDOPERULTATU"            => $operador,
                    "IDATIVO"                 => $row["IDATIVO"]
                );

                $this->ClassificacaoDeTarefasFactory->insertCrmClassificacaoDeTarefas($params);
            } else {
                $this->checkExistingClassificacaoDeTarefas($nrorg, $row);
                $params = array(
                    "NRSEQCLASSIFICATAREFA"   => $row["NRSEQCLASSIFICATAREFA"],
                    "DSCLASSIFICATAREFA"   => $row["DSCLASSIFICATAREFA"],
                    "NRORGULTATU"       => $nrorg,
                    "NRORG"             => $nrorg,
                    "CDOPERULTATU"      => $operador,
                    "IDATIVO"           => $row["IDATIVO"]
                );

                $this->ClassificacaoDeTarefasFactory->editCrmClassificacaoDeTarefas($params);

            }
            }
            
             $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function checkExistingClassificacaoDeTarefas ($nrorg, $row)
    {
        try {
            $params = array(
                "NRSEQCLASSIFICATAREFA"   => $row["NRSEQCLASSIFICATAREFA"],
                "DSCLASSIFICATAREFA"   => $row["DSCLASSIFICATAREFA"],
                "NRORG"             => $nrorg,
            );
            
            $existe =  $this->ClassificacaoDeTarefasFactory->checkExistingClassificacaoDeTarefas($params);
            if ($existe > 0 ) {
                throw new \Exception("EXISTE");
            }
        } catch (\Exception $ex) {
            throw $ex;
        }
    }

    public function deleteCrmClassificacaoDeTarefas ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "NRSEQCLASSIFICATAREFA"   => $item["NRSEQCLASSIFICATAREFA"],
                    "NRORG" => $nrorg,
                );

                $this->ClassificacaoDeTarefasFactory->deleteCrmClassificacaoDeTarefas($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

}