<?php

namespace CRM\Service;

use CRM\Factory\CrmPerfilDeAtividadeFactory;
use Teknisa\Libs\Util\Environment;
use Teknisa\Libs\Util\NewCode;
use Doctrine\ORM\EntityManager;

class CrmPerfilDeAtividadeService
{

    protected $PerfilDeAtividadeFactory;
    protected $Environment;
    protected $newCode;
    protected $connection;

    public function __construct(Environment $Environment, NewCode $newCode, EntityManager $entityManager, CrmPerfilDeAtividadeFactory $PerfilDeAtividadeFactory)
    {
        $this->PerfilDeAtividadeFactory                 = $PerfilDeAtividadeFactory;
        $this->Environment                  = $Environment;
        $this->newCode                      = $newCode;
        $this->connection                   = $entityManager->getConnection();
    }

    public function getCrmPerfilDeAtividade()
    {
        return $this->PerfilDeAtividadeFactory->getCrmPerfilDeAtividade();
    }

    public function getCrmPerfilDeAtividadeOperador($params)
    {
        $nrorg = $this->Environment->getNrorg();
        $dataparams = array (
            "NRORG" => $nrorg,
            "NRSEQPERFATIV" => $params["NRSEQPERFATIV"],
        );
        return $this->PerfilDeAtividadeFactory->getCrmPerfilDeAtividadeOperador($dataparams);
    }
    

    public function saveCrmPerfilDeAtividade($row)
    { 

       $this->connection->beginTransaction();
       try{
        $nrorg = $this->Environment->getNrorg();
        $operador = $this->Environment->getCdOperador();

            if ($row["NRSEQPERFATIV"] == null) {
                $this->checkExistingPerfilDeAtividade($nrorg, $row);
                $novoCodigo = $this->newCode->getCodeByTableName("CRM_PERFILATIV", $nrorg, 1, 5, false);
                    $params = array(
                    "NRSEQPERFATIV"     => $novoCodigo,
                    "DESCPEFATIV"       => $row["DESCPEFATIV"],
                    "IDDASHPADR"        => $row["IDDASHPADR"],
                    "IDATIVO"           => $row["IDATIVO"],
                    "NRORG"             => $nrorg,
                    "NRORGINCLUSAO"     => $nrorg,
                    "CDOPERINCLUSAO"    => $operador,
                    "IDEXIBEPAINELVENDAS"    => $row["IDEXIBEPAINELVENDAS"],
                    "IDEXIBEPAINELATEND"    => $row["IDEXIBEPAINELATEND"],
                );

                $this->PerfilDeAtividadeFactory->insertCrmPerfilDeAtividade($params);
            } else {
                $this->checkExistingPerfilDeAtividade($nrorg, $row);
                $params = array(
                    "NRSEQPERFATIV"     => $row["NRSEQPERFATIV"],
                    "DESCPEFATIV"       => $row["DESCPEFATIV"],
                    "IDDASHPADR"          => $row["IDDASHPADR"],
                    "NRORGULTATU"       => $nrorg,
                    "NRORG"             => $nrorg,
                    "IDATIVO"           => $row["IDATIVO"],
                    "CDOPERULTATU"      => $operador,
                    "IDEXIBEPAINELVENDAS"    => $row["IDEXIBEPAINELVENDAS"],
                    "IDEXIBEPAINELATEND"    => $row["IDEXIBEPAINELATEND"],
                );

                $this->PerfilDeAtividadeFactory->editCrmPerfilDeAtividade($params);

            }
            
            
             $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }

    public function checkExistingPerfilDeAtividade ($nrorg, $row)
    {
        try {
            $params = array(
                "DESCPEFATIV"       => $row["DESCPEFATIV"],
                "NRSEQPERFATIV"     => $row["NRSEQPERFATIV"]);
       
            
            $existe =  $this->PerfilDeAtividadeFactory->checkExistingPerfilDeAtividade($params);
            if ($existe > 0 ) {
                throw new \Exception("EXISTE");
            }
        } catch (\Exception $ex) {
            throw $ex;
        }
    }

    public function deleteCrmPerfilDeAtividade ($params)
    {
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrOrg();

            foreach ($params["NRS"] as $item) {

                $params = array(
                    "NRSEQPERFATIV"   => $item["NRSEQPERFATIV"],
                    "NRORG" => $nrorg,
                );

                $this->PerfilDeAtividadeFactory->deleteCrmPerfilDeAtividade($params);
            }

            $this->connection->commit();
        } catch (\Exception $e) {
            $this->connection->rollback();
            throw $e;
        }
    }

    public function getCrmPerfilDeAtividadeOperadores($params)
    {
        $nrorg = $this->Environment->getNrorg();
        $dataparams = array (
            "NRORG" => $nrorg
        );
        return $this->PerfilDeAtividadeFactory->getCrmPerfilDeAtividadeOperadores($dataparams);
    }
    
    
    public function getCrmPerfilModalMetas($params)
    {
        $nrorg = $this->Environment->getNrorg();
        $dataparams = array (
            "NRORG" => $nrorg
        );
        return $this->PerfilDeAtividadeFactory->getCrmPerfilModalMetas($dataparams);
    }

    public function getCrmPerfilDeAtividadeMetas($params)
    {
    
        $nrorg = $this->Environment->getNrorg();


        $dataparams = array (
            "NRORG" => $nrorg,
            "NRSEQPERFATIV" => $params["NRSEQPERFATIV"],
                    
        );
        return $this->PerfilDeAtividadeFactory->getCrmPerfilDeAtividadeMetas($dataparams);
    }



    public function saveCrmPerfilOperador($row) 
    { 
    
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();
        
            // Verifique se a chave CDOPERADOR existe
            if (isset($row["CDOPERADOR"]) && $row["CDOPERADOR"] == null) {
                $params = array(
                    "CDOPERADOR" => $operador, 
                    "NMOPERADOR"  => $row["NMOPERADOR"],
                );
    
                $this->PerfilDeAtividadeFactory->insertCrmPerfilOperador($params);
            } elseif (isset($rowmet["CDOPERADOR"]) && $rowmet["CDOPERADOR"] == null) {
                $params = array(
                    "CDOPERADOR" => $operador, 
                    "NMOPERADOR"  => $row["NMOPERADOR"],
                );
            }
            
            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }
    


    public function saveCrmPerfilMeta($rowmet) 
    { 
        var_dump ($rowmet);
        die;
        $this->connection->beginTransaction();
        try {
            $nrorg = $this->Environment->getNrorg();
            $operador = $this->Environment->getCdOperador();
            
            // Gera o novo código fora do if/else
            $novoCodigo = $this->newCode->getCodeByTableName("CRM_OPERMETA", $nrorg, 1, 5, false);
    
            // Verifique se a chave NROPERMETA existe
            if (isset($rowmet["NROPERMETA"]) && $rowmet["NROPERMETA"] == null) {
                $params = array(
                    "NROPERMETA" => $novoCodigo,
                    "NRSEQPERFATIV" => $rowmet["NRSEQPERFATIV"],
                    "NRMETAS" => $rowmet["NRMETAS"],
                    "CDOPERADOR" => $rowmet["CDOPERADOR"], // Corrigido para garantir que está passando o valor correto
                    "NRORG" => $nrorg,
                    "NRORGINCLUSAO" => $nrorg,
                    "CDOPERINCLUSAO" => $operador, // Garantir que o operador é passado
                    "DTINCLUSAO" => $rowmet["DTINCLUSAO"],
                );
    
                $this->PerfilDeAtividadeFactory->insertCrmPerfilMeta($params);
            } elseif (isset($rowmet["CDOPERADOR"]) && $rowmet["CDOPERADOR"] == null) {
                $params = array(
                    "NROPERMETA" => $novoCodigo,
                    "NRSEQPERFATIV" => $rowmet["NRSEQPERFATIV"],
                    "NRMETAS" => $rowmet["NRMETAS"],
                    "CDOPERADOR" => $operador, // Garantir que o operador correto seja passado
                    "NRORG" => $nrorg,
                    "NRORGINCLUSAO" => $nrorg,
                    "CDOPERINCLUSAO" => $operador,
                    "DTINCLUSAO" => $rowmet["DTINCLUSAO"],
                );
    
                $this->PerfilDeAtividadeFactory->editCrmPerfilMeta($params);
            }
            
            $this->connection->commit();
        } catch (\Exception $ex) {
            $this->connection->rollback();
            throw $ex;
        }
    }
    

}