import { Utilities } from '@/util/Utilities';
import {
  Form,
  LoadingService,
  Modal,
  ModalService,
  Select, Tabs, TextInput,
} from
  '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekGrid } from '@zeedhi/teknisa-components-common';

export class CrmPerfilDeAtividadeController {
  private visibilidadeGridDePerfilDeAtividade: boolean = true;

  private currentRow : any = {};

  private modalAdicionarPerfilDeAtividade!: Modal;

  private modalAdicionarPerfilOperador: any;

  private modalAdicionarPerfilMeta!: Modal;

  public async openModalNewPerfilDeAtividade() {
    this.modalAdicionarPerfilDeAtividade = await ModalService.createFromJson('crm_perfil_de_atividade/Modal/crm_perfil_de_atividade_modal_cadastro', true);
    await this.modalAdicionarPerfilDeAtividade.show();
  }

  public async openModalNewPerfilOperador() {
    this.modalAdicionarPerfilOperador = await ModalService.createFromJson('crm_perfil_de_atividade/Modal/crm_perfil_operador_modal_cadastro', true);
    await this.modalAdicionarPerfilOperador.show();
  }

  public closeModalOperador() {
    this.modalAdicionarPerfilOperador.hide();
    this.modalAdicionarPerfilOperador?.destroy();
  }

  public async abrirModalPerfilNovaMeta() {
    this.modalAdicionarPerfilMeta = await ModalService.createFromJson('crm_perfil_de_atividade/Modal/crm_perfil_meta_modal_cadastro', true);
    await this.modalAdicionarPerfilMeta.show();
  }

  public fecharModalPerfilNovaMeta() {
    this.modalAdicionarPerfilMeta.hide();
    this.modalAdicionarPerfilMeta?.destroy();
  }

  public closeModal() {
    this.modalAdicionarPerfilDeAtividade.hide();
    this.modalAdicionarPerfilDeAtividade?.destroy();
  }

  public saveCrmPerfilDeAtividade() {
    const formulario = Metadata.getInstance<Form>('form-adicionarPerfilDeAtividade');
    const gridPerfil = Metadata.getInstance<TekGrid>('tek-grid-crmPerfilDeAtividade_grid');
    if (Utilities.validateForm(formulario)) {
      LoadingService.show();
      Http.post('/saveCrmPerfilDeAtividade', {
        NRSEQPERFATIV: Metadata.getInstance<TextInput>('NRSEQPERFATIV-MODAL-PERFIL').value,
        DESCPEFATIV: Metadata.getInstance<TextInput>('DESCPEFATIV-MODAL-PERFIL').value,
        IDATIVO: Metadata.getInstance<Select>('IDATIVO-MODAL-PERFIL').value,
        IDDASHPADR: Metadata.getInstance<TextInput>('IDDASHPADR-MODAL-PERFIL').value,
        IDEXIBEPAINELVENDAS: Metadata.getInstance<Select>('IDEXIBEPAINELVENDAS-MODAL-PERFIL').value,
        IDEXIBEPAINELATEND: Metadata.getInstance<Select>('IDEXIBEPAINELATEND-MODAL-PERFIL').value,
      }).then(() => {
        gridPerfil.datasource.get();
        this.closeModal();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        LoadingService.hide();
      });
    } else {
      Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
    }
  }

  public get visibilidadeFramePerfilDeAtividade() {
    return !this.visibilidadeGridDePerfilDeAtividade;
  }

  public abrirFramePerfilDeAtividade({ row }: any) {
    this.visibilidadeGridDePerfilDeAtividade = false;
    this.currentRow = row;
    this.carregarTabPerfilDeAtividadeData(row);
    this.changeActiveTab();
  }

  public voltarTekGridPerfilDeAtividade(): void {
    this.visibilidadeGridDePerfilDeAtividade = true;
  }

  private carregarTabPerfilDeAtividadeData(row: any): void {
    Metadata.getInstance<TextInput>('formPerfilDeAtividadeData-NRSEQPERFATIV').value = row.NRSEQPERFATIV;
    Metadata.getInstance<TextInput>('formPerfilDeAtividadeData-DESCPEFATIV').value = row.DESCPEFATIV;
    Metadata.getInstance<Select>('formPerfilDeAtividadeData-IDATIVO').value = row.IDATIVO;
    Metadata.getInstance<TextInput>('formPerfilDeAtividadeData-IDDASHPADR').value = row.IDDASHPADR;
    Metadata.getInstance<Select>('formPerfilDeAtividadeData-IDEXIBEPAINELVENDAS').value = row.IDEXIBEPAINELVENDAS;
    Metadata.getInstance<Select>('formPerfilDeAtividadeData-IDEXIBEPAINELATEND').value = row.IDEXIBEPAINELATEND;
  }

  public clickButtonToExpand({ component }: any): void {
    const form = Metadata.getInstance<Form>(component.name.split('_')[1]);
    form.isVisible = !form.isVisible;
    component.iconName = (component.iconName === 'mdi-chevron-down') ? 'mdi-chevron-right' : 'mdi-chevron-down';
  }

  get textFramePerfilDeAtividadeName(): string {
    return this.currentRow.DESCPEFATIV;
  }

  public changeActiveTab(): void {
    const tabs = Metadata.getInstance<Tabs>('tabsInformationPerfilDeAtividade');
    const activeTab = tabs.tabs[tabs.activeTab];

    switch (activeTab.name) {
      case 'tab_operador':
        setTimeout(() => {
          this.setFilterGridPerfilOperador();
        }, 100);
        break;
      default:
        // Do nothing
        break;
    }

    switch (activeTab.name) {
      case 'tab_metas':
        setTimeout(() => {
          this.setFilterGridPerfilMetas();
        }, 100);
        break;
      default:
        // Do nothing
        break;
    }

    switch (activeTab.name) {
      case 'tab_motivoDeEvolucao':
        setTimeout(() => {
          this.setFilterGridPerfilMotivoEvo();
        }, 100);
        break;
      default:
        // Do nothing
        break;
    }

    switch (activeTab.name) {
      case 'tab_resultado':
        setTimeout(() => {
          this.setFilterGridPerfilResultado();
        }, 100);
        break;
      default:
        // Do nothing
        break;
    }
  }

  public setFilterGridPerfilOperador() {
    const gridPerfilOperador = Metadata.getInstance<TekGrid>('tekgrid-perfiloperador-tab');
    gridPerfilOperador.datasource.setFilter({
      NRSEQPERFATIV: this.currentRow.NRSEQPERFATIV,
    });
  }

  public setFilterGridPerfilMetas() {
    const gridPerfilMetas = Metadata.getInstance<TekGrid>('tek-grid-crmPerfilMetas_grid');
    gridPerfilMetas.datasource.setFilter({
      NRSEQPERFATIV: this.currentRow.NRSEQPERFATIV,
    });
  }

  public setFilterGridPerfilMotivoEvo() {
    const gridPerfilMotivoEvo = Metadata.getInstance<TekGrid>('tek-grid-CrmPerfilMotivoDeEvolucao_grid');
    gridPerfilMotivoEvo.datasource.setFilter({
      NRSEQPERFATIV: this.currentRow.NRSEQPERFATIV,
    });
  }

  public setFilterGridPerfilResultado() {
    const gridPerfilResultado = Metadata.getInstance<TekGrid>('tek-grid-CrmPerfilResultadoDaEvolucao_grid');
    gridPerfilResultado.datasource.setFilter({
      NRSEQPERFATIV: this.currentRow.NRSEQPERFATIV,
    });
  }

  public saveCrmPerfilOperador() {
    const formulario = Metadata.getInstance<Form>('container-perfil-operador-tab');
    const gridPerfil = Metadata.getInstance<TekGrid>('tekgrid-perfiloperador-tab');
    if (Utilities.validateForm(formulario)) {
      LoadingService.show();
      Http.post('/saveCrmPerfilOperador', {
        NRSEQPERFATIV: this.currentRow.NRSEQPERFATIV,
        CDOPERADOR: this.currentRow.CDOPERADOR,
        NMOPERADOR: Metadata.getInstance<Select>('modal-cadastro-operador-CDOPER').value,
      }).then(() => {
        gridPerfil.datasource.get();
        this.closeModalOperador();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        error.showErrorMessage();
      }).finally(() => {
        LoadingService.hide();
      });
    } else {
      Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
    }
  }

  public saveCrmPerfilMeta(row :any) {
    const formulario = Metadata.getInstance<Form>('form-adicionarPerfilMeta');
    const gridPerfil = Metadata.getInstance<TekGrid>('tek-grid-crmPerfilMetas_grid');
    if (Utilities.validateForm(formulario)) {
      LoadingService.show();
      Http.post('/saveCrmPerfilMeta', {
        NRMETAS: Metadata.getInstance<Select>('modal-cadastro-meta-NRMETAS').value,
        NRSEQPERFATIV: this.currentRow.NRSEQPERFATIV,
        NRORG: this.currentRow.NRORG,
        CDOPERADOR: Metadata.getInstance<Select>('tekgrid-perfiloperador-tab').value = row.CDOPERADOR,
        DTINCLUSAO: this.currentRow.DTINCLUSAO,
        NRORGINCLUSAO: this.currentRow.NRORG,
        CDOPERINCLUSAO: this.currentRow.CDOPERADOR,
        NROPERMETA: this.currentRow.NROPERMETA,
      }).then(() => {
        gridPerfil.datasource.get();
        this.fecharModalPerfilNovaMeta();
        Utilities.showSuccessMessage();
      }).catch((error: any) => {
        // Verifica se o método showErrorMessage está presente no erro
        if (error && typeof error.showErrorMessage === 'function') {
          error.showErrorMessage();
        } else {
          // Caso não tenha, mostra uma mensagem de erro genérica
          console.error('Erro ao salvar Perfil Meta: ', error);
          Utilities.alertMessage('Ocorreu um erro ao salvar a meta.', 'error');
        }
      }).finally(() => {
        LoadingService.hide();
      });
    } else {
      Utilities.alertMessage('Existem campos obrigatórios não preenchidos!', 'error');
    }
  }
}
